GroupLayout

Struct GroupLayout 

pub struct GroupLayout {
    pub num_layers: u32,
    pub num_blocks: u32,
    pub num_kv_heads: u16,
    pub group_stride: u64,
    pub fs_block_size: u64,
}

Fields

num_layers: u32num_blocks: u32num_kv_heads: u16group_stride: u64

block_size × head_dim × elem_bytes, rounded up to fs_block_size.

fs_block_size: u64

Filesystem block size (4 KiB on most NVMe). Group stride is a multiple.

Implementations

Source

impl GroupLayout

pub fn new( num_layers: u32, num_blocks: u32, num_kv_heads: u16, block_size: u32, head_dim: u32, elem_bytes: u32, fs_block_size: u64, ) -> Self

pub fn bytes_per_layer(&self) -> u64

Bytes occupied by one full layer in its file (K + V across all blocks).

pub fn file_offset(&self, key: GroupKey) -> u64

File offset for key within its layer’s file.

pub fn group_id(&self, key: GroupKey) -> GroupId

Dense GroupId for key.

pub fn group_bytes(&self) -> u64

Number of bytes a single group occupies on disk (== group_stride).

pub fn block_bytes(&self) -> u64

Bytes in one full block: K + V across all kv-heads, each a group_stride-pitch group. This is the contiguous unit the block-granular StorageBackend ops read/write in one operation.