dispatch

Function dispatch 

pub fn dispatch<A: SlotArena, S: SwapStore>(
    res: &mut Residency<A, S>,
    op: u8,
    key: u64,
) -> PagingReply
Execute one control op against the residency and return the reply. Pure over the (already unit-tested) Residency, so the protocol is testable without a socket or RDMA.